@@ -6,7 +6,7 @@ use Carp ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.02';
+	$VERSION = '0.03';
 }
 
 use Object::Tiny qw{
@@ -43,4 +43,15 @@ sub new {
 	return $self;
 }
 
+
+
+
+
+#####################################################################
+# Stringification
+
+sub as_string {
+	return $_[0]->string;
+}
+
 1;
